@@ -29,13 +29,6 @@ lapply(
       fixed.x = FALSE
     )
     set.seed(seed)
-    results_null <- MC(
-      fit,
-      R = R,
-      alpha = c(0.001, 0.01, 0.05),
-      decomposition = NULL
-    )
-    set.seed(seed)
     results_chol <- MC(
       fit,
       R = R,
@@ -64,21 +57,6 @@ lapply(
     answers <- cbind(
       answers
     )
-    testthat::test_that(
-      paste(text, "NULL"),
-      {
-        testthat::expect_equal(
-          results_null$thetahat$est,
-          lavaan::parameterEstimates(fit)$est,
-          check.attributes = FALSE
-        )
-        testthat::expect_true(
-          abs(
-            .MCCI(results_null)["cp", "97.5%"] - quantile(answers[, "cp"], .975, na.rm = TRUE)
-          ) <= tol
-        )
-      }
-    )
     testthat::test_that(
       paste(text, "chol"),
       {
@@ -89,7 +67,13 @@ lapply(
         )
         testthat::expect_true(
           abs(
-            .MCCI(results_chol)["cp", "97.5%"] - quantile(answers[, "cp"], .975, na.rm = TRUE)
+            .MCCI(
+              results_chol
+            )["cp", "97.5%"] - quantile(
+              answers[, "cp"],
+              .975,
+              na.rm = TRUE
+            )
           ) <= tol
         )
       }
@@ -104,7 +88,12 @@ lapply(
         )
         testthat::expect_true(
           abs(
-            .MCCI(results_eigen)["cp", "97.5%"] - quantile(answers[, "cp"], .975)
+            .MCCI(
+              results_eigen
+            )["cp", "97.5%"] - quantile(
+              answers[, "cp"],
+              .975
+            )
           ) <= tol
         )
       }
@@ -119,7 +108,13 @@ lapply(
         )
         testthat::expect_true(
           abs(
-            .MCCI(results_svd)["cp", "97.5%"] - quantile(answers[, "cp"], .975, na.rm = TRUE)
+            .MCCI(
+              results_svd
+            )["cp", "97.5%"] - quantile(
+              answers[, "cp"],
+              .975,
+              na.rm = TRUE
+            )
           ) <= tol
         )
       }
